# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`unicorn`](#unicorn): Install and run unicorn.
* [`unicorn::params`](#unicornparams): Params class with default values.

### Defined types

* [`unicorn::app`](#unicornapp): Defines a unicorn application

## Classes

### <a name="unicorn"></a>`unicorn`

Install and run unicorn.

#### Examples

##### 

```puppet
unicorn::app { 'my-sinatra-app':
  approot     => '/opt/my-sinatra-app',
  pidfile     => '/opt/my-sinatra-app/unicorn.pid',
  socket      => '/opt/my-sinatra-app/unicorn.sock',
  user        => 'sinatra',
  group       => 'sinatra',
  preload_app => true,
  rack_env    => 'production',
  source      => 'bundler',
  require     => [
    Class['ruby::dev'],
    Bundler::Install[$app_root],
  ],
}
```

#### Parameters

The following parameters are available in the `unicorn` class:

* [`export_home`](#export_home)
* [`manage_package`](#manage_package)
* [`ensure`](#ensure)
* [`provider`](#provider)

##### <a name="export_home"></a>`export_home`

Data type: `Any`

Path to export the HOME environment.

Default value: ``undef``

##### <a name="manage_package"></a>`manage_package`

Data type: `Any`

Whether to manage the unicorn package.

Default value: ``true``

##### <a name="ensure"></a>`ensure`

Data type: `Any`

State to ensure the unicorn package.

Default value: `'present'`

##### <a name="provider"></a>`provider`

Data type: `Any`

The provider used to ensure the unicorn package.

Default value: `'gem'`

### <a name="unicornparams"></a>`unicorn::params`

Params class with default values.

## Defined types

### <a name="unicornapp"></a>`unicorn::app`

Defines a unicorn application

#### Parameters

The following parameters are available in the `unicorn::app` defined type:

* [`approot`](#approot)
* [`pidfile`](#pidfile)
* [`socket`](#socket)
* [`listens`](#listens)
* [`export_home`](#export_home)
* [`backlog`](#backlog)
* [`workers`](#workers)
* [`user`](#user)
* [`group`](#group)
* [`config_file`](#config_file)
* [`config_template`](#config_template)
* [`initscript`](#initscript)
* [`init_time`](#init_time)
* [`logdir`](#logdir)
* [`rack_env`](#rack_env)
* [`preload_app`](#preload_app)
* [`source`](#source)
* [`extra_settings`](#extra_settings)

##### <a name="approot"></a>`approot`

Data type: `Any`

Path to the application working directory.

##### <a name="pidfile"></a>`pidfile`

Data type: `Any`

Path to the PID file.

##### <a name="socket"></a>`socket`

Data type: `Any`

Path to socket file.

##### <a name="listens"></a>`listens`

Data type: `Any`

Additional listen directives other than the default socket.

Default value: `[]`

##### <a name="export_home"></a>`export_home`

Data type: `Any`

Path to export the HOME environment.

Default value: ``undef``

##### <a name="backlog"></a>`backlog`

Data type: `Any`

Value to set for the backlog on the listening socket.

Default value: `'2048'`

##### <a name="workers"></a>`workers`

Data type: `Any`

Number of worker_processes to run.

Default value: `$facts['processors']['count']`

##### <a name="user"></a>`user`

Data type: `Any`

Specify the user to run unicorn as.

Default value: `'root'`

##### <a name="group"></a>`group`

Data type: `Any`

Specify the group to run unicorn as.

Default value: `'root'`

##### <a name="config_file"></a>`config_file`

Data type: `Any`

The path to install the configuration file.

Default value: ``undef``

##### <a name="config_template"></a>`config_template`

Data type: `Any`

The source template for the configuration file.

Default value: `'unicorn/config_unicorn.config.rb.erb'`

##### <a name="initscript"></a>`initscript`

Data type: `Any`

The template to use for the unicorn init script.

Default value: ``undef``

##### <a name="init_time"></a>`init_time`

Data type: `Any`

The time in seconds between checks for the old unicorn process during a service reload.

Default value: `15`

##### <a name="logdir"></a>`logdir`

Data type: `Any`

Path to the application log directory.

Default value: `"${approot}/log"`

##### <a name="rack_env"></a>`rack_env`

Data type: `Any`

The rack environment mode to start as.

Default value: `'production'`

##### <a name="preload_app"></a>`preload_app`

Data type: `Any`

Whether to preload the application before forking worker processes.

Default value: ``false``

##### <a name="source"></a>`source`

Data type: `Any`

The daemon source used to run the application.

Default value: `'system'`

##### <a name="extra_settings"></a>`extra_settings`

Data type: `Any`

A hash of additional settings to pass directly intol the application configuration file.

Default value: `{}`

